from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import (
    ClassVar as _ClassVar,
    Iterable as _Iterable,
    Mapping as _Mapping,
    Optional as _Optional,
    Union as _Union,
)

DESCRIPTOR: _descriptor.FileDescriptor

class GetUserListRequest(_message.Message):
    __slots__ = ["access_token"]
    ACCESS_TOKEN_FIELD_NUMBER: _ClassVar[int]
    access_token: str
    def __init__(self, access_token: _Optional[str] = ...) -> None: ...

class GetUserListResponse(_message.Message):
    __slots__ = ["results"]
    RESULTS_FIELD_NUMBER: _ClassVar[int]
    results: _containers.RepeatedCompositeFieldContainer[UserInList]
    def __init__(self, results: _Optional[_Iterable[_Union[UserInList, _Mapping]]] = ...) -> None: ...

class GetUserRequest(_message.Message):
    __slots__ = ["access_token", "id"]
    ACCESS_TOKEN_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    access_token: str
    id: str
    def __init__(self, access_token: _Optional[str] = ..., id: _Optional[str] = ...) -> None: ...

class GetUserResponse(_message.Message):
    __slots__ = ["email"]
    EMAIL_FIELD_NUMBER: _ClassVar[int]
    email: str
    def __init__(self, email: _Optional[str] = ...) -> None: ...

class UserInList(_message.Message):
    __slots__ = ["email"]
    EMAIL_FIELD_NUMBER: _ClassVar[int]
    email: str
    def __init__(self, email: _Optional[str] = ...) -> None: ...



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

import grpc_auth_service.role_service_pb2 as role__service__pb2


class AdminRoleStub:
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.GetUser = channel.unary_unary(
            "/AdminRole/GetUser",
            request_serializer=role__service__pb2.GetUserRequest.SerializeToString,
            response_deserializer=role__service__pb2.GetUserResponse.FromString,
        )
        self.GetUserList = channel.unary_unary(
            "/AdminRole/GetUserList",
            request_serializer=role__service__pb2.GetUserListRequest.SerializeToString,
            response_deserializer=role__service__pb2.GetUserListResponse.FromString,
        )


class AdminRoleServicer:
    """Missing associated documentation comment in .proto file."""

    def GetUser(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def GetUserList(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")


def add_AdminRoleServicer_to_server(servicer, server):
    rpc_method_handlers = {
        "GetUser": grpc.unary_unary_rpc_method_handler(
            servicer.GetUser,
            request_deserializer=role__service__pb2.GetUserRequest.FromString,
            response_serializer=role__service__pb2.GetUserResponse.SerializeToString,
        ),
        "GetUserList": grpc.unary_unary_rpc_method_handler(
            servicer.GetUserList,
            request_deserializer=role__service__pb2.GetUserListRequest.FromString,
            response_serializer=role__service__pb2.GetUserListResponse.SerializeToString,
        ),
    }
    generic_handler = grpc.method_handlers_generic_handler("AdminRole", rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


# This class is part of an EXPERIMENTAL API.
class AdminRole:
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def GetUser(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/AdminRole/GetUser",
            role__service__pb2.GetUserRequest.SerializeToString,
            role__service__pb2.GetUserResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def GetUserList(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/AdminRole/GetUserList",
            role__service__pb2.GetUserListRequest.SerializeToString,
            role__service__pb2.GetUserListResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: role_service.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x12role_service.proto"2\n\x0eGetUserRequest\x12\x14\n\x0c\x61\x63\x63\x65ss_token\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t" \n\x0fGetUserResponse\x12\r\n\x05\x65mail\x18\x01 \x01(\t"*\n\x12GetUserListRequest\x12\x14\n\x0c\x61\x63\x63\x65ss_token\x18\x01 \x01(\t"\x1b\n\nUserInList\x12\r\n\x05\x65mail\x18\x01 \x01(\t"3\n\x13GetUserListResponse\x12\x1c\n\x07results\x18\x01 \x03(\x0b\x32\x0b.UserInList2s\n\tAdminRole\x12,\n\x07GetUser\x12\x0f.GetUserRequest\x1a\x10.GetUserResponse\x12\x38\n\x0bGetUserList\x12\x13.GetUserListRequest\x1a\x14.GetUserListResponseb\x06proto3'
)

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "role_service_pb2", globals())
if _descriptor._USE_C_DESCRIPTORS is False:

    DESCRIPTOR._options = None
    _GETUSERREQUEST._serialized_start = 22
    _GETUSERREQUEST._serialized_end = 72
    _GETUSERRESPONSE._serialized_start = 74
    _GETUSERRESPONSE._serialized_end = 106
    _GETUSERLISTREQUEST._serialized_start = 108
    _GETUSERLISTREQUEST._serialized_end = 150
    _USERINLIST._serialized_start = 152
    _USERINLIST._serialized_end = 179
    _GETUSERLISTRESPONSE._serialized_start = 181
    _GETUSERLISTRESPONSE._serialized_end = 232
    _ADMINROLE._serialized_start = 234
    _ADMINROLE._serialized_end = 349
# @@protoc_insertion_point(module_scope)
